PlatformViewSize class

Constructors

PlatformViewSize(double? width, double? height)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
height → double?
final
isZero → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

ceil() → PlatformViewSize
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override