ypay_inventory
library
Enums
CashbackBadgeColor
Color that will be used to create cashback badge
CashbackBadgeVariant
Cashback badge formatting variant
SplitBadgeColor
Color of split that will be used to configure the badge
SplitBadgeVariant
Variant of split that will be used to configure the badge
YPayBadgeAlign
Align that will be used to configure the badge
YPayBadgeHidingPolicy
Defines the visibility of badge if it is unavailable
YPayBadgeTheme
Theme that will be used to configure the badge
YPayWidgetBackground
Background options for the widget. You can choose a standard look,
make the background transparent, or apply a custom color.
Use YPayBnplPreviewWidgetView.setBackgroundColor for setting custom color.
Header options for the widget. You can choose standard view
or minified (without logo and title). Click handling only works
with the standard header.
YPayWidgetSize
Size style options for the widget. This affects the margins
between widget elements and the padding. WidgetSize.MEDIUM is used by default.
YPayWidgetStyle
Background style for the widget. You may choose to
set solid color or leave the widget transparent.
YPayWidgetTheme
Widget's coloring theme. You may choose to set the dark theme,
the light theme, or respect the theme, set in the system
YPayWidgetType
Widget's type. You can configure the widget to upload
the split info, the cashback info or both